@@ -22,7 +22,7 @@
 # ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 # POSSIBILITY OF SUCH DAMAGE.
 package Game::Collisions::AABB;
-$Game::Collisions::AABB::VERSION = '0.3';
+$Game::Collisions::AABB::VERSION = '0.4';
 use utf8;
 use v5.14;
 use warnings;
@@ -133,7 +133,7 @@ sub does_collide
 
     return $maxx1 >= $minx2
         && $minx1 <= $maxx2 
-        && $maxy1 >= $miny1 
+        && $maxy1 >= $miny2 
         && $miny1 <= $maxy2;
 }
 
@@ -338,7 +338,8 @@ sub remove
 
     my $parent = $self->parent;
     $self->set_parent( undef );
-    $parent->_prune;
+    # If there's only one node in the system, there will be no parent
+    $parent->_prune if defined $parent;
 
     return;
 }
